## START: Set by rpmautospec
## (rpmautospec version 0.7.3)
## RPMAUTOSPEC: autorelease, autochangelog
%define autorelease(e:s:pb:n) %{?-p:0.}%{lua:
    release_number = 1;
    base_release_number = tonumber(rpm.expand("%{?-b*}%{!?-b:1}"));
    print(release_number + base_release_number - 1);
}%{?-e:.%{-e*}}%{?-s:.%{-s*}}%{!?-n:%{?dist}}
## END: Set by rpmautospec

# require network, so disabled by default
# to run on mock, use --enable-network
# only a couple of tests fail
%bcond_with tests

%global forgeurl https://github.com/datalad/datalad

Name:           python-datalad
Version:        1.2.0
%global tag     %{version}
%forgemeta
Release:        %autorelease
Summary:        Keep code, data, containers under control with git and git-annex

License:        MIT
URL:            %{forgeurl}
Source0:        %{forgesource}

BuildArch:      noarch

%global _description %{expand:
DataLad makes data management and data distribution more accessible. To do
that, it stands on the shoulders of Git and Git-annex to deliver a
decentralized system for data exchange. This includes automated ingestion of
data from online portals and exposing it in readily usable form as Git(-annex)
repositories, so-called datasets. The actual data storage and permission
management, however, remains with the original data providers.

The full documentation is available at https://docs.datalad.org and
https://handbook.datalad.org provides a hands-on crash-course on DataLad

Extensions:

A number of extensions are available that provide additional functionality for
DataLad. Extensions are separate packages that are to be installed in addition
to DataLad. In order to install DataLad customized for a particular domain, one
can simply install an extension directly, and DataLad itself will be
automatically installed with it. An annotated list of extensions is available
in the DataLad handbook.

Support:

The documentation for this project is found here: https://docs.datalad.org

If you have a problem or would like to ask a question about how to use DataLad,
please submit a question to NeuroStars.org with a datalad tag. NeuroStars.org
is a platform similar to StackOverflow but dedicated to neuroinformatics.

All previous DataLad questions are available here:
https://neurostars.org/tags/datalad/}

%description %_description

%package -n python3-datalad
Summary:        %{summary}
BuildRequires:  python3-devel
BuildRequires:  python3-pytest
BuildRequires:  git-core
BuildRequires:  git-annex
# for 7za
BuildRequires:  p7zip
BuildRequires:  p7zip-plugins
# Not added automatically
Requires:       git-annex
Requires:       p7zip p7zip-plugins
Provides:       datalad = %{version}-%{release}

%description -n python3-datalad %_description

%prep
%forgesetup

# tweak test requirements
# - remove type packages
# - remove mypy
# - remove pytest-fail-slow
sed -i -e '/types-python-dateutil/ d' \
    -e '/types-requests/ d' \
    -e '/mypy/ d' \
    -e '/pytest-fail-slow/ d' \
    setup.py

# Do not read deps from tox.ini, just use setup.py
# tox.ini calls requirements.txt which doesn't work
rm -f tox.ini

# Correct shebangs in tools
find . -type f -exec sed -i "s|#!/usr/bin/env.*python$|#!%{python3}|" '{}' ';'

# remove shebangs
find datalad/resources/procedures/ -type f -name "*.py" -exec sed -i '/^#![  ]*\/usr\/bin\/env.*$/ d' {} 2>/dev/null ';'

# required for tests, and man page generation
git config --global user.name "Your Name"
git config --global user.email "youremail@yourdomain.com"

%if %{with tests}
# Tests wants a git repo
git init .
git add .
git commit -m "Dummy commit"

# correct function argument auto_spec -> autospec
sed -i 's/auto_spec/autospec/' datalad/support/tests/test_annexrepo.py
%endif

%generate_buildrequires
%pyproject_buildrequires %{?with_tests:-x tests}

%build
%pyproject_wheel
# build man pages
%{python3} setup.py build_manpage

%install
%pyproject_install
%pyproject_save_files datalad

# install man pages
install -m 0644 -p -Dt $RPM_BUILD_ROOT/%{_mandir}/man1/  build/man/*.1


%check
%if %{with tests}
export PATH="${PATH}:%{buildroot}/%{_bindir}"
%pytest
%endif
# check import
# exclude imports that require a dataset
%pyproject_check_import -e *test* -e *cfg_text2git* -e *cfg_yoda*

%files -n python3-datalad -f %{pyproject_files}
%doc README.md CONTRIBUTORS CONTRIBUTING.md CHANGELOG.md CODE_OF_CONDUCT.md
%{_bindir}/datalad
%{_bindir}/git-annex-remote-datalad
%{_bindir}/git-annex-remote-datalad-archives
%{_bindir}/git-annex-remote-ora
%{_bindir}/git-annex-remote-ria
%{_bindir}/git-credential-datalad
%{_mandir}/man1/*.1*

%changelog
## START: Generated by rpmautospec
* Wed May 21 2025 Packit <hello@packit.dev> - 1.2.0-1
- Update to 1.2.0 upstream release
- Resolves: rhbz#2367066

* Sat Jan 18 2025 Fedora Release Engineering <releng@fedoraproject.org> - 1.1.5-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_42_Mass_Rebuild

* Sun Dec 15 2024 Packit <hello@packit.dev> - 1.1.5-1
- Update to 1.1.5 upstream release
- Resolves: rhbz#2332438

* Mon Nov 18 2024 Packit <hello@packit.dev> - 1.1.4-1
- Update to 1.1.4 upstream release
- Resolves: rhbz#2327098

* Thu Aug 08 2024 Packit <hello@packit.dev> - 1.1.3-1
- Update to 1.1.3 upstream release
- Resolves: rhbz#2303617

* Thu Jul 25 2024 Packit <hello@packit.dev> - 1.1.2-1
- Update to 1.1.2 upstream release
- Resolves: rhbz#2299982

* Fri Jul 19 2024 Fedora Release Engineering <releng@fedoraproject.org> - 1.1.1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_41_Mass_Rebuild

* Wed Jul 03 2024 Packit <hello@packit.dev> - 1.1.1-1
- Update to 1.1.1 upstream release
- Resolves: rhbz#2295616

* Mon Jun 24 2024 Packit <hello@packit.dev> - 1.1.0-1
- Update to 1.1.0 upstream release
- Resolves: rhbz#2276164

* Sat Jun 08 2024 Python Maint <python-maint@redhat.com> - 1.0.1-2
- Rebuilt for Python 3.13

* Wed Apr 17 2024 Packit <hello@packit.dev> - 1.0.1-1
- Update to 1.0.1 upstream release
- Resolves: rhbz#2275407

* Sat Apr 06 2024 Packit <hello@packit.dev> - 1.0.0-1
- Update to 1.0.0 upstream release
- Resolves: rhbz#2273791

* Fri Feb 02 2024 Packit <hello@packit.dev> - 0.19.6-1
- [packit] 0.19.6 upstream release
- Resolves rhbz#2262462

* Fri Jan 26 2024 Fedora Release Engineering <releng@fedoraproject.org> - 0.19.5-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_40_Mass_Rebuild

* Mon Jan 22 2024 Fedora Release Engineering <releng@fedoraproject.org> - 0.19.5-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_40_Mass_Rebuild

* Thu Dec 28 2023 Packit <hello@packit.dev> - 0.19.5-1
- [packit] 0.19.5 upstream release
- Resolves rhbz#2256119

* Wed Dec 13 2023 Packit <hello@packit.dev> - 0.19.4-1
- [packit] 0.19.4 upstream release
- Resolves rhbz#2254288

* Thu Aug 10 2023 Packit <hello@packit.dev> - 0.19.3-1
- [packit] 0.19.3 upstream release

* Thu Aug 10 2023 Ankur Sinha (Ankur Sinha Gmail) <sanjay.ankur@gmail.com> - 0.19.2-2
- chore: add packit conf

* Sat Jul 22 2023 Ankur Sinha (Ankur Sinha Gmail) <sanjay.ankur@gmail.com> - 0.19.2-1
- feat: update to 0.19.2 (fixes rhbz#2214827)

* Fri Jul 21 2023 Fedora Release Engineering <releng@fedoraproject.org> - 0.18.4-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_39_Mass_Rebuild

* Tue Jul 04 2023 Python Maint <python-maint@redhat.com> - 0.18.4-2
- Rebuilt for Python 3.12

* Tue May 16 2023 Ankur Sinha (Ankur Sinha Gmail) <sanjay.ankur@gmail.com> - 0.18.4-1
- feat: update to 0.18.4 (fixes rhbz#2207697)

* Tue Mar 28 2023 Ankur Sinha (Ankur Sinha Gmail) <sanjay.ankur@gmail.com> - 0.18.3-1
- feat: update to 0.18.3 (fixes rhbz#2181754)

* Tue Feb 28 2023 Ankur Sinha (Ankur Sinha Gmail) <sanjay.ankur@gmail.com> - 0.18.2-1
- feat: update to 0.18.2 (fixes rhbz#2173638)

* Fri Jan 20 2023 Fedora Release Engineering <releng@fedoraproject.org> - 0.18.1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_38_Mass_Rebuild

* Mon Jan 16 2023 Ankur Sinha (Ankur Sinha Gmail) <sanjay.ankur@gmail.com> - 0.18.1-1
- feat: update to 0.18.1 (fixes rhbz#2073563)

* Mon Jan 16 2023 Ankur Sinha (Ankur Sinha Gmail) <sanjay.ankur@gmail.com> - 0.18.0-1
- feat: update to 0.18.0

* Fri Jul 22 2022 Fedora Release Engineering <releng@fedoraproject.org> - 0.15.6-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_37_Mass_Rebuild

* Thu Jun 16 2022 Python Maint <python-maint@redhat.com> - 0.15.6-2
- Rebuilt for Python 3.11

* Fri Mar 04 2022 Ankur Sinha (Ankur Sinha Gmail) <sanjay.ankur@gmail.com> - 0.15.6-1
- feat: update to 0.15.6

* Fri Mar 04 2022 Ankur Sinha (Ankur Sinha Gmail) <sanjay.ankur@gmail.com> - 0.14.7-3
- chore: drop doc sub package

* Fri Jan 21 2022 Fedora Release Engineering <releng@fedoraproject.org> - 0.14.7-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_36_Mass_Rebuild

* Fri Sep 10 2021 Ankur Sinha (Ankur Sinha Gmail) <sanjay.ankur@gmail.com> - 0.14.7-1
- feat: init
## END: Generated by rpmautospec
